==> pyformex-0.9.0.tar.gz: pyformex-0.9.0/pyformex/plugins/wrl.py <==
# $Id: c18c8aa on Mon Jan 16 20:33:48 2012 +0000 by Benedict Verhegghe $
##
##  This file is part of pyFormex 0.9.0  (Mon Mar 25 13:52:29 CET 2013)
##  pyFormex is a tool for generating, manipulating and transforming 3D
##  geometrical models by sequences of mathematical operations.
##  Home page: http://pyformex.org
##  Project page:  http://savannah.nongnu.org/projects/pyformex/
##  Copyright 2004-2012 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be) 
##  Distributed under the GNU General Public License version 3 or later.
##
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with this program.  If not, see http://www.gnu.org/licenses/.
##
"""Wrl

"""
from __future__ import print_function

from numpy import *
from gui.draw import *

_prop_ = 0
_name_ = "_dummy_"


def name(s):
    global _name_
    _name_ = str(s)


def position(*args):
    pass

    
def IndexedFaceSet(coords,faces=None):
    global _prop_
    _prop_ += 1
    coords = asarray(coords).reshape(-1,3)
    print(coords.shape,_prop_)
    F = Formex(coords,_prop_)
    print(F.prop)
    draw(F)
    export({"%s-%s" % (_name_,'coords'):F})
    if faces is None:
        return

    
def IndexedLineSet(coords,lines):
    coords = asarray(coords).reshape(-1,3)
    print(coords.shape)
    F = Formex(coords,_prop_)
    draw(F)
    export({"%s-%s" % (_name_,'coords'):F})
    lines = column_stack([lines[:-1],lines[1:]])
    print(lines.shape)
    G = Formex(coords[lines],_prop_)
    export({_name_:G})
    draw(G)
   




# End

==> pyformex-1.0.6.tar.gz: pyformex-1.0.6/pyformex/plugins/wrl.py <==
#
##
##  This file is part of pyFormex 1.0.6  (Tue Mar 19 11:06:48 CET 2019)
##  pyFormex is a tool for generating, manipulating and transforming 3D
##  geometrical models by sequences of mathematical operations.
##  Home page: http://pyformex.org
##  Project page:  http://savannah.nongnu.org/projects/pyformex/
##  Copyright 2004-2018 (C) Benedict Verhegghe (benedict.verhegghe@ugent.be)
##  Distributed under the GNU General Public License version 3 or later.
##
##  This program is free software: you can redistribute it and/or modify
##  it under the terms of the GNU General Public License as published by
##  the Free Software Foundation, either version 3 of the License, or
##  (at your option) any later version.
##
##  This program is distributed in the hope that it will be useful,
##  but WITHOUT ANY WARRANTY; without even the implied warranty of
##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##  GNU General Public License for more details.
##
##  You should have received a copy of the GNU General Public License
##  along with this program.  If not, see http://www.gnu.org/licenses/.
##
"""Wrl

"""
from __future__ import absolute_import, division, print_function


from numpy import *
from pyformex.gui.draw import *

_prop_ = 0
_name_ = "_dummy_"


def name(s):
    global _name_
    _name_ = str(s)


def position(*args):
    pass


def IndexedFaceSet(coords,faces=None):
    global _prop_
    _prop_ += 1
    coords = asarray(coords).reshape(-1, 3)
    print(coords.shape, _prop_)
    F = Formex(coords, _prop_)
    print(F.prop)
    draw(F)
    export({"%s-%s" % (_name_, 'coords'):F})
    if faces is None:
        return


def IndexedLineSet(coords, lines):
    coords = asarray(coords).reshape(-1, 3)
    print(coords.shape)
    F = Formex(coords, _prop_)
    draw(F)
    export({"%s-%s" % (_name_, 'coords'):F})
    lines = column_stack([lines[:-1], lines[1:]])
    print(lines.shape)
    G = Formex(coords[lines], _prop_)
    export({_name_:G})
    draw(G)





# End
